summer

package module
v0.0.0-...-798fb04 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 15, 2026 License: Apache-2.0 Imports: 8 Imported by: 1

README

Summer (is here)

The plan is to build something that loosely follows jsonrpc 2.0. That still allows for extensions in all directions.

Since im a huge Gin fanboy, it will be modelled as a gin.HandlerFunc that you mount where you want it.

TODO

  • Should each request spawn it's own registry with the methods that its identity have access to?

    and then figure out a way to cache it for http-requests.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func HTTP

func HTTP() gin.HandlerFunc

HTTP is a gin.HandlerFunc based on the default framework instance

func HttpProxy

func HttpProxy(verb, url, contentType string) func(*api.Request) *api.Response

Proxy will forward params to the provided url using the provided verb.

func Init

func Init() *framework.Summer

Init creates a new instance of the framework

func Register

func Register(name string, handler api.Handler)

Register registers a handler to the provided name in the default framework instance

func WS

func WS() gin.HandlerFunc

func Wrap

func Wrap[T any, K any](delegate func(*T) (*K, error)) func(*api.Request) *api.Response

Wrap will wrap any (T)=>K, error func and allow you to turn it into a jsonrpc func.

Types

This section is empty.

Directories

Path Synopsis

Jump to